==> dtsmake-0.0.3.tgz: package/lib/index.js <==
/// <reference path="../typings/tsd.d.ts" />
/**
 * dtsmake command line interface
 */
var program = require("commander");
var dtsmake_1 = require("./dtsmake");
var child_process = require("child_process");
var myPackage = require("../package.json");
var srcFiles = function (val) {
    return val.split(",");
};
var plugins = function (val) {
    return val.split(",");
};
//var distDir:string = "";
var defFiles = function (val) {
    return val.split(",");
};
var extraFiles = function (val) {
    console.log("[EXTRA]" + val);
    return val.split(",");
};
program
    .version(myPackage.version, "-v, --version")
    .option("-s, --src <path>", "[MUST] target javascript file path", srcFiles)
    .option("--dist [value]", "outout d.ts file path. no need `.d.ts` file extension.")
    .option("-n, --n [value]", "module name")
    .option("-p, --plugin <names>", "tern.js plugin. see tern.js server plugin(http://ternjs.net/doc/manual.html#plugins)", plugins)
    .option("-d, --def <paths>", "tern.js def files. DEFAULT:'ecma5'", defFiles)
    .option("-x, --extrafiles <paths>", "sample files for target js lib. help for ternjs type inference.", extraFiles)
    .option("-D, --debug", "debug output mode")
    .option("-A, --voidAsAny", "force output `void` to `any`")
    .option("-i, --interfaceSameNameVar", "export a namespace property same with a interface name", true)
    .option("-a, --annotateTypeInstance", "annotate interface's constructor type as return type instance", true)
    .option("-g, --globalObject [value]", "how to export objects that same name with JS Global Object; \"remove\" or \"wrap\" or \"rename\"; DEFAULT:\"wrap\" ")
    .option("-N, --NodeJSModule", "nodejs module special replace")
    .option("-e, --export", "add export statement in a bottom of d.ts file")
    .option("-S, --exportStyle [value]", "if --outExport true, select export style \"es6\" or \"legacy\"")
    .option("-M, --exportModuleName [value]", 'exporting module name. ex. "EXAMPLE"; usage `import example = require("EXAMPLE");`')
    .parse(process.argv);
if (!program.src) {
    console.warn("--src option is MUST.");
    program.help();
}
else if (program.exportStyle && !program.export) {
    console.warn("--exportStyle option needs --export option.");
    process.exit(1);
}
else if (program.exportModuleName && !program.export) {
    console.warn("--exportModuleName option needs --export option.");
    process.exit(1);
}
/**
 *
 * `tern/bin/condense [--name name] [--plugin name]* [--def name]* [+extrafile.js]* [file.js]+`
 */
var genCommand = function () {
    var s = "";
    s = "node \"" + __dirname + "/../node_modules/tern/bin/condense\"";
    s += program.n ? " --name " + program.n : "";
    s += program.plugin ? " --plugin " + program.plugin.join(" ") : "";
    s += program.def ? " --def " + program.def.join(" ") : "";
    s += program.extrafiles ? " +" + program.extrafiles.join(" +") : "";
    s += " " + program.src.join(" ");
    s += " --no-spans";
    console.log(program.name());
    console.log("[CMD]" + s);
    console.log("[SRC]" + program.src.join(" "));
    return s;
};
/**
 * exec tern/bin/condense
 */
var child = child_process.exec(genCommand(), { maxBuffer: 1000000 * 2048 }, function (err, stdout, stderr) {
    if (err) {
        console.warn("[INFO] tern/condense error");
        console.error(err.toString());
        return;
    }
    else if (stderr) {
        console.warn("[INFO] tern/condense error");
        console.error(stderr.toString());
        return;
    }
    else {
        if (program.debug)
            console.log(stdout.toString("utf8"));
        //
        var dg = new dtsmake_1.dtsmake.DTSMake();
        var op = {
            isDebug: program.debug,
            isOutVoidAsAny: program.voidAsAny,
            isAnnotateTypeInstance: program.annotateTypeInstance,
            isExportInterfaceSameNameVar: program.interfaceSameNameVar,
            isNodeJsModule: program.NodeJSModule,
            isOutExport: program.export,
        };
        if (program.exportStyle)
            op.exportStyle = program.exportStyle;
        if (program.exportModuleName)
            op.exportModuleName = program.exportModuleName;
        if (program.globalObject)
            op.globalObject = program.globalObject;
        dg.main(stdout.toString(), program.dist ? program.dist : program.src.toString().replace(/\.[a-z0-9]+$/, ""), op);
    }
});

==> dtsmake-0.0.4.tgz: package/lib/index.js <==
/// <reference path="../typings/tsd.d.ts" />
/**
 * dtsmake command line interface
 */
var program = require("commander");
var dtsmake_1 = require("./dtsmake");
var child_process = require("child_process");
var myPackage = require("../package.json");
var srcFiles = function (val) {
    return val.split(",");
};
var plugins = function (val) {
    return val.split(",");
};
//var distDir:string = "";
var defFiles = function (val) {
    return val.split(",");
};
var extraFiles = function (val) {
    console.log("[EXTRA]" + val);
    return val.split(",");
};
program
    .version(myPackage.version, "-v, --version")
    .option("-s, --src <path>", "[MUST] target javascript file path", srcFiles)
    .option("--dist [value]", "outout d.ts file path. no need `.d.ts` file extension.")
    .option("-n, --n [value]", "module name")
    .option("-p, --plugin <names>", "tern.js plugin. see tern.js server plugin(http://ternjs.net/doc/manual.html#plugins)", plugins)
    .option("-d, --def <paths>", "tern.js def files. DEFAULT:'ecma5'", defFiles)
    .option("-x, --extrafiles <paths>", "sample files for target js lib. help for ternjs type inference.", extraFiles)
    .option("-D, --debug", "debug output mode")
    .option("-A, --voidAsAny", "force output `void` to `any`")
    .option("-i, --interfaceSameNameVar", "export a namespace property same with a interface name", true)
    .option("-a, --annotateTypeInstance", "annotate interface's constructor type as return type instance", true)
    .option("-g, --globalObject [value]", "how to export objects that same name with JS Global Object; \"remove\" or \"wrap\" or \"rename\"; DEFAULT:\"wrap\" ")
    .option("-N, --NodeJSModule", "nodejs module special replace")
    .option("-e, --export", "add export statement in a bottom of d.ts file")
    .option("-S, --exportStyle [value]", "if --outExport true, select export style \"es6\" or \"legacy\"")
    .option("-M, --exportModuleName [value]", 'exporting module name. ex. "EXAMPLE"; usage `import example = require("EXAMPLE");`')
    .parse(process.argv);
if (!program.src) {
    console.warn("--src option is MUST.");
    program.help();
}
else if (program.exportStyle && !program.export) {
    console.warn("--exportStyle option needs --export option.");
    process.exit(1);
}
else if (program.exportModuleName && !program.export) {
    console.warn("--exportModuleName option needs --export option.");
    process.exit(1);
}
/**
 *
 * `tern/bin/condense [--name name] [--plugin name]* [--def name]* [+extrafile.js]* [file.js]+`
 */
var genCommand = function () {
    var s = "";
    s = "node \"" + __dirname + "/../node_modules/tern/bin/condense\"";
    s += program.n ? " --name " + program.n : "";
    //s += (<any>program).plugin ? ` --plugin ${(<any>program).plugin.join(" ")}` : "";
    if (program.plugin) {
        for (var i in program.plugin) {
            s += " --plugin " + program.plugin[i];
        }
    }
    //s += (<any>program).def ? ` --def ${(<any>program).def.join(" ")}` : "";
    if (program.def) {
        for (var i in program.def) {
            s += " --def " + program.def[i];
        }
    }
    s += program.extrafiles ? " +" + program.extrafiles.join(" +") : "";
    s += " " + program.src.join(" ");
    s += " --no-spans";
    console.log(program.name() + " started.");
    console.log("[CMD]" + s);
    console.log("[SRC]" + program.src.join(" "));
    return s;
};
/**
 * exec tern/bin/condense
 */
var child = child_process.exec(genCommand(), { maxBuffer: 1000000 * 2048 }, function (err, stdout, stderr) {
    if (err) {
        console.warn("[INFO] tern/condense error");
        console.error(err.toString());
        return;
    }
    else if (stderr) {
        console.warn("[INFO] tern/condense error");
        console.error(stderr.toString());
        return;
    }
    else {
        if (program.debug)
            console.log(stdout.toString("utf8"));
        //
        var dg = new dtsmake_1.dtsmake.DTSMake();
        var op = {
            isDebug: program.debug,
            isOutVoidAsAny: program.voidAsAny,
            isAnnotateTypeInstance: program.annotateTypeInstance,
            isExportInterfaceSameNameVar: program.interfaceSameNameVar,
            isNodeJsModule: program.NodeJSModule,
            isOutExport: program.export,
        };
        if (program.exportStyle)
            op.exportStyle = program.exportStyle;
        if (program.exportModuleName)
            op.exportModuleName = program.exportModuleName;
        if (program.globalObject)
            op.globalObject = program.globalObject;
        dg.main(stdout.toString(), program.dist ? program.dist : program.src.toString().replace(/\.[a-z0-9]+$/, ""), op);
    }
});
